@@ -34,3 +34,21 @@ def truncate_or_pad(byte_string, size=None):
         return bytes(byte_array + b"\0"*(size-length))
     else:
         return byte_string
+
+
+def equals(val1, val2):
+    """
+    Returns True if the two strings are equal, False otherwise.
+
+    The time taken is independent of the number of characters that match.
+
+    For the sake of simplicity, this function executes in constant time only
+    when the two strings have the same length. It short-circuits when they
+    have different lengths.
+    """
+    if len(val1) != len(val2):
+        return False
+    result = 0
+    for x, y in zip(val1, val2):
+        result |= ord(x) ^ ord(y)
+    return result == 0
